/*
 * libstorage
 *
 * Copyright (c) 2016 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *	 http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <unistd.h>
#include <libmount.h>
#include "common.h"

#define BLOCK_CONF_FILE         "/etc/storaged/block.conf"

int is_compat_bind_mount(void)
{
	struct libmnt_table *t = NULL;
	int r = 0;
	struct libmnt_fs *fs;

	t = mnt_new_table();
	if (!t)
		return 0;

	r = mnt_table_parse_mtab(t, NULL);
	if (r < 0) {
		//LCOV_EXCL_START System Error
		mnt_free_table(t);
		return 0;
		//LCOV_EXCL_STOP
	}

	fs = mnt_table_find_target(t, COMPAT_DIR, MNT_ITER_BACKWARD);
	if (fs) {
		// TODO : mnt_fs_get_root(fs) should be matched to tzplatform_getenv(TZ_USER_CONTENT).
		mnt_free_table(t);
		return 1;
	}

	//LCOV_EXCL_START System Error
	mnt_free_table(t);
	return 0;
	//LCOV_EXCL_STOP
}

int storage_ext_is_supported(void)
{
	static int support = -1;

	if (support >= 0)
		return support;

	if (access(BLOCK_CONF_FILE, R_OK) == 0)
		support = 1;
	else
		support = 0;

	return support;
}

